@@ -1,20 +1,20 @@
-#	$Id: Storable.pm,v 1.9 2007-02-03 15:23:19 adam Exp $
+#   $Id: Storable.pm 69 2014-05-23 10:27:30Z adam $
 
 package Config::Trivial::Storable;
 
 use base qw( Config::Trivial );
 
-use 5.006;
+use 5.010;
 use strict;
 use Carp;
 use warnings;
 use Storable qw(lock_store lock_retrieve);
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 my ( $_package, $_file ) = caller;
 
 #
-#	STORE
+#   STORE
 #
 
 sub store {
@@ -25,7 +25,8 @@ sub store {
         || $self->{_storable_file}
         || $self->{_config_file};
 
-    if (   ( ( $self->{_self} ) && ( $file =~ '\(eval ' ) )
+    if ( (   ( $self->{_self} )
+          && ( ( $file =~ '\(eval ' ) || ( $file =~ 'base.pm' ) ) )
         || ( $_file eq $file )
         || ( $0     eq $file ) )
     {
@@ -47,13 +48,13 @@ sub store {
             q{Configuration object isn't a HASH reference.})
     };
 
-    lock_store $settings, $file;
+    lock_store $settings, $file or croak "Unable to store to $file";
 
     return 1;
 }
 
 #
-#	RETRIEVE
+#   RETRIEVE
 #
 
 sub retrieve {
@@ -81,9 +82,11 @@ sub retrieve {
             $file = $self->{_storable_file};
         }
         else {
+            no warnings qw( uninitialized );
             if ((      ( $self->{_self} )
                     && ( defined $self->{_config_file} )
-                    && ( $self->{_config_file} =~ '\(eval ' )
+                    && (  ( $self->{_config_file} =~ '\(eval ' )
+                       || ( $self->{_config_file} =~ 'base.pm' ) )
                 )
                 || ( $_file eq $self->{_config_file} )
                 || ( $0     eq $self->{_config_file} )
@@ -123,10 +126,11 @@ sub set_storable_file {
     my $self               = shift;
     my $configuration_file = shift;
 
-    if ( $self->_check_file($configuration_file) ) {
+    if ( $self->_check_file( $configuration_file ) ) {
         $self->{_storable_file} = $configuration_file;
         $self->{_self}          = 0;
-        if ( $self->{_config_file} =~ '\(eval ' ) {
+        if ( ( $self->{_config_file} =~ '\(eval ' )
+                ||  ($self->{_config_file} =~ 'base.pm' ) ) {
             delete $self->{_config_file};
         }
         return $self;
@@ -142,18 +146,19 @@ __END__
 
 =head1 NAME
 
-Config::Trivial::Storable - Very simple tool for reading and writing very simple Storable configuration files
+Config::Trivial::Storable - Very simple tool for reading and writing
+very simple Storable configuration files
 
 =head1 VERSION
 
-This documentation refers to Config::Trivial::Storable version 0.30
+This documentation refers to Config::Trivial::Storable version 0.31
 
 =head1 SYNOPSIS
 
   use Config::Trivial::Storable;
   my $config = Config::Trivial::Storable->new(config_file => "path/to/my/config.conf");
   my $settings = $config->retrieve;
-  print "Setting Colour is:\t", $settings->{'colour'};
+  say "Setting Colour is:\t", $settings->{'colour'};
   $settings->{'new-item'} = "New Setting";
   $settings->store;
 
@@ -189,9 +194,14 @@ To store data in the internal use the set_configuration data
 method. The option to pass a hash_ref in this method may
 be removed in future versions.
 
+If you do not specify a file name then the module will default to
+writing to the calling file - which is obviously silly and it will
+try to avoid doing this - hence the error message:
+"Can't retrieve store from the calling file.".
+
 =head2 retrieve
 
-This is the analog to read, only it reads data from a Storable binary.
+This is the analogue to read, only it reads data from a Storable binary.
 
   $config->retrieve;
 
@@ -255,23 +265,22 @@ L<perl>, L<Config::Trivial>, L<Storable>.
 
 =head1 LICENSE AND COPYRIGHT
 
-This version as C<Config::Trivial::Storable>, Copyright iredale consulting 2006-2007
+This version as C<Config::Trivial::Storable>, Copyright Adam John Trickett 2006-2014
 
 OSI Certified Open Source Software.
+Free Software Foundation Free Software.
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published
-by the Free Software Foundation; either version 2 of the License,
-or (at your option) any later version.
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU Lesser General Public License as published
+by the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-GNU General Public License for more details. 
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-MA  02111, USA.
+You should have received a copy of the GNU Lesser General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 =cut
